@@ -16,9 +16,6 @@ if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
-
-import sys
-
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -30,6 +27,7 @@ __all__ = (
     "AnomalyScoreTypeDef",
     "AnomalySubscriptionTypeDef",
     "AnomalyTypeDef",
+    "CostCategoryProcessingStatusTypeDef",
     "CostCategoryReferenceTypeDef",
     "CostCategoryRuleTypeDef",
     "CostCategoryTypeDef",
@@ -43,6 +41,7 @@ __all__ = (
     "DateIntervalTypeDef",
     "DimensionValuesTypeDef",
     "DimensionValuesWithAttributesTypeDef",
+    "EBSResourceUtilizationTypeDef",
     "EC2InstanceDetailsTypeDef",
     "EC2ResourceDetailsTypeDef",
     "EC2ResourceUtilizationTypeDef",
@@ -196,6 +195,12 @@ class AnomalyTypeDef(_RequiredAnomalyTypeDef, _OptionalAnomalyTypeDef):
     pass
 
 
+CostCategoryProcessingStatusTypeDef = TypedDict(
+    "CostCategoryProcessingStatusTypeDef",
+    {"Component": Literal["COST_EXPLORER"], "Status": Literal["PROCESSING", "APPLIED"]},
+    total=False,
+)
+
 CostCategoryReferenceTypeDef = TypedDict(
     "CostCategoryReferenceTypeDef",
     {
@@ -204,6 +209,8 @@ CostCategoryReferenceTypeDef = TypedDict(
         "EffectiveStart": str,
         "EffectiveEnd": str,
         "NumberOfRules": int,
+        "ProcessingStatus": List["CostCategoryProcessingStatusTypeDef"],
+        "Values": List[str],
     },
     total=False,
 )
@@ -223,7 +230,9 @@ _RequiredCostCategoryTypeDef = TypedDict(
     },
 )
 _OptionalCostCategoryTypeDef = TypedDict(
-    "_OptionalCostCategoryTypeDef", {"EffectiveEnd": str}, total=False
+    "_OptionalCostCategoryTypeDef",
+    {"EffectiveEnd": str, "ProcessingStatus": List["CostCategoryProcessingStatusTypeDef"]},
+    total=False,
 )
 
 
@@ -232,7 +241,22 @@ class CostCategoryTypeDef(_RequiredCostCategoryTypeDef, _OptionalCostCategoryTyp
 
 
 CostCategoryValuesTypeDef = TypedDict(
-    "CostCategoryValuesTypeDef", {"Key": str, "Values": List[str]}, total=False
+    "CostCategoryValuesTypeDef",
+    {
+        "Key": str,
+        "Values": List[str],
+        "MatchOptions": List[
+            Literal[
+                "EQUALS",
+                "STARTS_WITH",
+                "ENDS_WITH",
+                "CONTAINS",
+                "CASE_SENSITIVE",
+                "CASE_INSENSITIVE",
+            ]
+        ],
+    },
+    total=False,
 )
 
 CoverageByTimeTypeDef = TypedDict(
@@ -354,6 +378,17 @@ DimensionValuesWithAttributesTypeDef = TypedDict(
     total=False,
 )
 
+EBSResourceUtilizationTypeDef = TypedDict(
+    "EBSResourceUtilizationTypeDef",
+    {
+        "EbsReadOpsPerSecond": str,
+        "EbsWriteOpsPerSecond": str,
+        "EbsReadBytesPerSecond": str,
+        "EbsWriteBytesPerSecond": str,
+    },
+    total=False,
+)
+
 EC2InstanceDetailsTypeDef = TypedDict(
     "EC2InstanceDetailsTypeDef",
     {
@@ -391,6 +426,7 @@ EC2ResourceUtilizationTypeDef = TypedDict(
         "MaxCpuUtilizationPercentage": str,
         "MaxMemoryUtilizationPercentage": str,
         "MaxStorageUtilizationPercentage": str,
+        "EBSResourceUtilization": "EBSResourceUtilizationTypeDef",
     },
     total=False,
 )
